@@ -2,11 +2,11 @@
 
 # called by uscan with '--upstream-version' <version> <file>
 DIR=mei-$2
-TAR=../libmei_$2.orig.tar.gz
+TAR=../libmei_$2.orig.tar.bz2
 
 # clean up the upstream tarball
 unzip $3
-tar -c -z -f $TAR $DIR
+tar -c -j -f $TAR $DIR
 rm -rf $DIR $3
 
 # move to directory 'tarballs'
